[SCM] Samba Shared Repository - branch master updated

Andrew Bartlett abartlet at samba.org
Mon Dec 6 21:49:01 UTC 2021


The branch, master has been updated
       via  05c09e8cfa0 heimdal_build: Prepare for Heimdal upgrade by only building HEIMDAL_ASN1_GEN_HOSTCC when needed.
       via  98cb41cb35d build: Remove kdc_include except where needed
       via  209a33670fa build: Only use embedded Heimdal include paths in an embedded Heimdal build
      from  d6380560f87 docs: fix documentation for default of "fruit:zero_file_id"

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 05c09e8cfa09d22b31b7da6b461413dfb807984a
Author: Andrew Bartlett <abartlet at samba.org>
Date:   Thu Dec 2 13:25:07 2021 +1300

    heimdal_build: Prepare for Heimdal upgrade by only building HEIMDAL_ASN1_GEN_HOSTCC when needed.
    
    This will otherwise break the system-heimdal build.
    
    This is correct regardless.
    
    Signed-off-by: Andrew Bartlett <abartlet at samba.org>
    Reviewed-by: Joseph Sutton <josephsutton at catalyst.net.nz>
    
    Autobuild-User(master): Andrew Bartlett <abartlet at samba.org>
    Autobuild-Date(master): Mon Dec  6 21:48:30 UTC 2021 on sn-devel-184

commit 98cb41cb35dfacbd5c6acfb13a0ac555b474da08
Author: Andrew Bartlett <abartlet at samba.org>
Date:   Thu Dec 2 11:47:35 2021 +1300

    build: Remove kdc_include except where needed
    
    This include was being set on too many subsystems, including some MIT-related.
    
    This was a problem because it would then trigger the mixing of MIT and Heimdal
    krb5.h files.  It is now only set on the plugins and services that use the
    embedded Heimdal KDC.
    
    BUG: https://bugzilla.samba.org/show_bug.cgi?id=14924
    
    Signed-off-by: Andrew Bartlett <abartlet at samba.org>
    Reviewed-by: Joseph Sutton <josephsutton at catalyst.net.nz>

commit 209a33670fab5dd7373444ae1ce76dbb5dfa0058
Author: Andrew Bartlett <abartlet at samba.org>
Date:   Thu Dec 2 11:33:02 2021 +1300

    build: Only use embedded Heimdal include paths in an embedded Heimdal build
    
    BUG: https://bugzilla.samba.org/show_bug.cgi?id=14924
    
    Signed-off-by: Andrew Bartlett <abartlet at samba.org>
    Reviewed-by: Joseph Sutton <josephsutton at catalyst.net.nz>

-----------------------------------------------------------------------

Summary of changes:
 buildtools/wafsamba/samba3.py       |  4 ++--
 source4/heimdal_build/wscript_build | 18 +++++++++---------
 source4/kdc/wscript_build           |  9 ---------
 3 files changed, 11 insertions(+), 20 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/heimdal_build/wscript_build b/source4/heimdal_build/wscript_build
index 079cac744f9..77519356575 100644
--- a/source4/heimdal_build/wscript_build
+++ b/source4/heimdal_build/wscript_build
@@ -856,21 +856,21 @@ HEIMDAL_SUBSYSTEM('HEIMDAL_VERS_HOSTCC',
        use_global_deps=False,
        use_hostcc=True)
 
-HEIMDAL_SUBSYSTEM('HEIMDAL_ASN1_GEN_HOSTCC',
-       'lib/asn1/gen.c',
-       includes='../heimdal/lib/asn1',
-       group='hostcc_build_main',
-       cflags=bld.env.HEIMDAL_UNPICKY_WNO_STRICT_OVERFLOW_CFLAGS,
-       deps='ROKEN_HOSTCC',
-       use_global_deps=False,
-       use_hostcc=True)
-
 HEIMDAL_SUBSYSTEM('HEIMDAL_VERS',
        'lib/vers/print_version.c ../heimdal_build/version.c',
         deps='roken replace')
 
 
 if not bld.CONFIG_SET('USING_SYSTEM_ASN1_COMPILE'):
+    HEIMDAL_SUBSYSTEM('HEIMDAL_ASN1_GEN_HOSTCC',
+                      'lib/asn1/gen.c',
+                      includes='../heimdal/lib/asn1',
+                      group='hostcc_build_main',
+                      cflags=bld.env.HEIMDAL_UNPICKY_WNO_STRICT_OVERFLOW_CFLAGS,
+                      deps='ROKEN_HOSTCC',
+                      use_global_deps=False,
+                      use_hostcc=True)
+
     # here is the asn1 compiler build rule
     HEIMDAL_BINARY('asn1_compile',
         'lib/asn1/gen_copy.c '
diff --git a/source4/kdc/wscript_build b/source4/kdc/wscript_build
index 0edca94e75f..c7f28a72342 100644
--- a/source4/kdc/wscript_build
+++ b/source4/kdc/wscript_build
@@ -58,7 +58,6 @@ bld.SAMBA_LIBRARY('HDB_SAMBA4',
 bld.SAMBA_LIBRARY('HDB_SAMBA4_PLUGIN',
                   source='hdb-samba4-plugin.c',
                   deps='hdb HDB_SAMBA4 samba-util samba-hostconfig ',
-                  includes=kdc_include,
                   link_name='modules/hdb/hdb_samba4.so',
                   realname='hdb_samba4.so',
                   install_path='${MODULESDIR}/hdb',
@@ -67,7 +66,6 @@ bld.SAMBA_LIBRARY('HDB_SAMBA4_PLUGIN',
 
 bld.SAMBA_SUBSYSTEM('KDC-SERVER',
                     source='kdc-server.c kdc-proxy.c',
-                    includes=kdc_include,
                     deps='''
                          krb5samba
                          ldb
@@ -83,7 +81,6 @@ elif bld.CONFIG_GET('SAMBA_USES_MITKDC'):
 
 bld.SAMBA_SUBSYSTEM('KPASSWD-SERVICE',
                     source=kpasswd_flavor_src,
-                    includes=kdc_include,
                     deps='''
                          krb5samba
                          samba_server_gensec
@@ -106,13 +103,11 @@ bld.SAMBA_SUBSYSTEM('WDC_SAMBA4',
 
 bld.SAMBA_SUBSYSTEM('sdb',
 	source='sdb.c',
-	includes=kdc_include,
 	deps='talloc krb5',
 	)
 
 bld.SAMBA_SUBSYSTEM('sdb_hdb',
 	source='sdb_to_hdb.c',
-	includes=kdc_include,
 	deps='talloc sdb hdb',
 	autoproto='sdb_hdb.h',
 	enabled=bld.CONFIG_SET('SAMBA4_USES_HEIMDAL')
@@ -120,7 +115,6 @@ bld.SAMBA_SUBSYSTEM('sdb_hdb',
 
 bld.SAMBA_SUBSYSTEM('sdb_kdb',
 	source='sdb_to_kdb.c',
-	includes=kdc_include,
 	deps='sdb kdb5',
 	autoproto='sdb_kdb.h',
 	enabled=bld.CONFIG_SET('HAVE_KDB_H')
@@ -128,7 +122,6 @@ bld.SAMBA_SUBSYSTEM('sdb_kdb',
 
 bld.SAMBA_SUBSYSTEM('PAC_GLUE',
 	source='pac-glue.c',
-        includes=kdc_include,
 	deps='ldb auth4_sam common_auth samba-credentials samba-hostconfig com_err'
 	)
 
@@ -143,12 +136,10 @@ bld.SAMBA_LIBRARY('db-glue',
 	source='db-glue.c',
 	deps='ldb auth4_sam common_auth samba-credentials sdb samba-hostconfig com_err RPC_NDR_IRPC MESSAGING',
 	private_library=True,
-        includes=kdc_include,
 	)
 
 bld.SAMBA_SUBSYSTEM('KPASSWD_GLUE',
         source='kpasswd_glue.c',
-        includes=kdc_include,
         deps='ldb com_err')
 
 bld.SAMBA_SUBSYSTEM('MIT_KDC_IRPC',


diff --git a/buildtools/wafsamba/samba3.py b/buildtools/wafsamba/samba3.py
index ebc7fbb707f..4277c5f6f2e 100644
--- a/buildtools/wafsamba/samba3.py
+++ b/buildtools/wafsamba/samba3.py
@@ -35,8 +35,8 @@ def s3_fix_kwargs(bld, kwargs):
 
     # the extra_includes list is relative to the source3 directory
     extra_includes = [ '.', 'include', 'lib' ]
-    # local heimdal paths only included when USING_SYSTEM_KRB5 is not set
-    if not bld.CONFIG_SET("USING_SYSTEM_KRB5"):
+    # local heimdal paths must only be included when using our embedded Heimdal
+    if bld.CONFIG_SET("USING_EMBEDDED_HEIMDAL"):
         extra_includes += [ '../source4/heimdal/lib/com_err',
                             '../source4/heimdal/lib/krb5',
                             '../source4/heimdal/lib/gssapi',
-- 
Samba Shared Repository



More information about the samba-cvs mailing list